@@ -12,6 +12,15 @@
 
 .First.lib <- function(lib, pkg){
     library.dynam("mixtools", pkg, lib)
-    cat('mixtools package version 0.3.0,  released February 2008\n')
+    DESCpath <- file.path(system.file(package="mixtools"), "DESCRIPTION")
+    info <- read.dcf(DESCpath)
+#   info <- read.dcf(file.path(lib, pkg, "DESCRIPTION")) does the same thing but
+#   the other way works even outside the .First.lib function
+    cat(pkg,'package version', info[,"Version"], '  Released', info[,"Date"], '\n')
     cat('Type help(package="mixtools") to get started.\n')
 }
+
+.Last.lib <- function(libpath){
+  library.dynam.unload("mixtools",libpath)
+}
+
